.. change-log documentation master file, created by
   sphinx-quickstart on Fri Nov  8 09:46:11 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to change-log's documentation!
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   subtool/log

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
